# boilercore

[![All Contributors](https://img.shields.io/github/all-contributors/softboiler/boilercore?color=ee8449&style=flat-square)](#contributors)

Common functionality of boiler repositories. To use `cachier` test adapter
functionality, install the hacked version which replaces `pickle` with `dill`.

```PowerShell
pip install 'cachier @ git+https://github.com/blakeNaccarato/cachier@db7f394a553a90944ca25c2d687771006e77a024'
```

## Project information

- [Changes](<https://softboiler.github.io/boilercore/changelog.html>)
- [Docs](<https://softboiler.github.io/boilercore>)
- [Contributing](<https://softboiler.github.io/boilercore/contributing.html>)

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://www.blakenaccarato.com/"><img src="https://avatars.githubusercontent.com/u/20692450?v=4?s=100" width="100px;" alt="Blake Naccarato"/><br /><sub><b>Blake Naccarato</b></sub></a><br /><a href="#code-blakeNaccarato" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
